require 'json'
require 'uri'
require 'logger'

require "snowagent/version"
require "snowagent/agent"
require "snowagent/sync_strategy"
require "snowagent/service"
require "snowagent/configuration"

begin
  require "rails/railtie"
  require "snowagent/railtie"
rescue LoadError
end

module SnowAgent
  class << self
    attr_writer :configuration
    attr_writer :logger

    def logger
      @logger ||= Logger.new(STDOUT)
    end

    def configuration
      @configuration ||= Configuration.new
    end

    def agent
      @agent ||= Agent.new(configuration)
    end

    def metric(*args)
      if configuration.configured?
        agent.metric(*args)
      else
        logger.warn "[SnowAgent] Metric '#{args.first}' was not send due to configuration."
      end

      nil
    end

    def time(key, context = nil)
      start = Time.now
      result = yield
      metric(key, ((Time.now - start) * 1000).round, "time", context)
      result
    end

    def increment(key, value = 1, context = nil)
      metric(key, value, "counter", context)
    end

    def amount(key, value, context = nil)
      metric(key, value, "amount", context)
    end

    def configure
      yield(configuration)
      # do not trigger initialization if not configured
      self.agent if configuration.configured?
    end
  end
end
